@@ -5,8 +5,9 @@
 
 rlomax <- function(n, scale = 1.0, shape = 4.0) {
   
-  if (scale <= 0) stop("'scale' must be > 0")
-  if (shape <= 0) stop("'shape' must be > 0")
+  ## if (scale <= 0) stop("'scale' must be > 0")
+  ## if (shape <= 0) stop("'shape' must be > 0")
+  if ((scale <= 0) || (shape <= 0)) return(rep(NaN, n))
   X <- (runif(n))^(-1/shape) 
   X <- scale*X
   X - scale
@@ -14,9 +15,10 @@ rlomax <- function(n, scale = 1.0, shape = 4.0) {
 }
 
 dlomax <- function(x, scale = 1.0, shape = 4.0, log = FALSE) {
-  
-  if (scale <= 0) stop("'scale' must be >0")
-  if (shape <= 0) stop("'shape' must be > 0")
+
+  ## if (scale <= 0) stop("'scale' must be >0")
+  ## if (shape <= 0) stop("'shape' must be > 0")
+  if ((scale <= 0) || (shape <= 0)) return(rep(NaN, length(x)))
   f <- rep(0, length(x))
   ind <- x > 0
   f[ind] <- log(shape) - (shape + 1)*log(scale + x[ind]) + shape*log(scale)
@@ -27,8 +29,9 @@ dlomax <- function(x, scale = 1.0, shape = 4.0, log = FALSE) {
 
 plomax <- function(q, scale = 1.0, shape = 4.0, lower.tail = FALSE) {
 
-  if (scale <= 0) stop("'scale' must be >0")
-  if (shape <= 0) stop("'shape' must be  >0")
+  ##if (scale <= 0) stop("'scale' must be >0")
+  ## if (shape <= 0) stop("'shape' must be  >0")
+  if ((scale <= 0) || (shape <= 0)) return(rep(NaN, length(q)))
   S <- rep(0, length(q))
   ind <- q > 0 
   S[ind] <- (scale / (scale + q[ind]) )^shape
@@ -40,8 +43,9 @@ plomax <- function(q, scale = 1.0, shape = 4.0, lower.tail = FALSE) {
 
 qlomax <- function(p, scale = 1.0, shape = 4.0) {
 
-  if (scale <= 0) stop("'scale' must be >0")
-  if (shape <= 0) stop("'shape' must be > 0")
+  ## if (scale <= 0) stop("'scale' must be >0")
+  ## if (shape <= 0) stop("'shape' must be > 0")
+  if ((scale <= 0) || (shape <= 0)) return(rep(NaN, length(p)))
   if ( any(p < 0) || any(p > 1) ) stop("'p' must be >=0 and <=1")
   lr <- -log(1-p) / shape  
   scale* (exp(lr) -1)
@@ -53,22 +57,23 @@ qlomax <- function(p, scale = 1.0, shape = 4.0) {
 ##=====================================================
 
 rSLTW <- function(n, delta = 1.0, shape = 1.0, scale = 1.0) {
-
-  if (delta <= 0) stop("'delta' must be >0")
-  if (shape <= 0) stop("'shape' must be >0")
-  if (scale <= 0) stop("'scale' must be >0")
-
+  
+  ## if (delta <= 0) stop("'delta' must be >0")
+  ## if (shape <= 0) stop("'shape' must be >0")
+  ## if (scale <= 0) stop("'scale' must be >0")
+  if ((delta <= 0) || (shape <= 0) || (scale <= 0)) return(rep(NaN, n))
   U <- runif(n)
   X <- ( delta^shape - (scale^shape)*log(U) )^(1/shape) - delta
   
 }
 
 dSLTW <- function(x, delta = 1.0, shape = 1.0, scale = 1.0, log = FALSE) {
-  
-  if (delta <= 0) stop("'delta' must be >0")
-  if (shape <= 0) stop("'shape' must be >0")
-  if (scale <= 0) stop("'scale' must be >0")
-  
+ 
+  ## if (delta <= 0) stop("'delta' must be >0")
+  ## if (shape <= 0) stop("'shape' must be >0")
+  ## if (scale <= 0) stop("'scale' must be >0")
+  if ((delta <= 0) || (shape <= 0) || (scale <= 0))  return(rep(NaN, length(x)))
+ 
   f <- rep(0, length(x))
   ind <- x > 0
   xs <- ( x[ind] + delta ) / scale 
@@ -80,11 +85,12 @@ dSLTW <- function(x, delta = 1.0, shape = 1.0, scale = 1.0, log = FALSE) {
 }
 
 pSLTW <- function(q, delta = 1.0, shape = 1.0, scale = 1.0,  lower.tail = FALSE) {
-  
-  if (delta <= 0) stop("'delta' must be >0")
-  if (shape <= 0) stop("'shape' must be >0")
-  if (scale <= 0) stop("'scale' must be >0")
 
+  ## if (delta <= 0) stop("'delta' must be >0")
+  ## if (shape <= 0) stop("'shape' must be >0")
+  ## if (scale <= 0) stop("'scale' must be >0")
+  if ((delta <= 0) || (shape <= 0) || (scale <= 0))  return(rep(NaN, length(q)))
+  
   S <- rep(0, length(q))
   ind <- q > 0 
   S[ind] <- exp( - ((q[ind] +delta)/scale)^shape + (delta/scale)^shape )
@@ -96,10 +102,11 @@ pSLTW <- function(q, delta = 1.0, shape = 1.0, scale = 1.0,  lower.tail = FALSE)
 
 qSLTW <- function(p, delta = 1.0,  shape = 1.0, scale = 1.0) {
   
-  if (delta <= 0) stop("'delta' must be >0")
-  if (shape <= 0) stop("'shape' must be >0")
-  if (scale <= 0) stop("'scale' must be >0")
-  
+  ## if (delta <= 0) stop("'delta' must be >0")
+  ## if (shape <= 0) stop("'shape' must be >0")
+  ## if (scale <= 0) stop("'scale' must be >0")
+  if ((delta <= 0) || (shape <= 0) || (scale <= 0))  return(rep(NaN, length(p)))
+
   if ( any(p < 0) || any(p > 1) ) stop("'p' must be >=0 and <=1")
 
   quant <- delta^shape - (scale^shape) * log(1-p)
